
def test_content_filters():
    """
    In this test, a content filter is created and used to filter some data.
    """

    from models import ContentFilter, MatchingAlgorithm

    content_filter = ContentFilter(
        id=0,
        server_id=0,
        name="Test Filter",
        matching_pattern="postcode lottery",
        matching_algorithm=MatchingAlgorithm.LITERAL,
        is_insensitive=True,
        is_whitelist=False
    )

    entry = {
        "title": "This is the Title of the test Entry",
        "description": "This is the description for the postcode lottery"
    }

    # Should match 'Test' in entry title with the pattern
    assert content_filter.matches(entry) == True

    print("success")


def test_content_duplicates():
    """
    In this test, two almost but not quite identical instances of `Content` are created, and
    checked against each other as duplicates.

    They should be considered duplicate, because not all fields need to match in order to be considered a duplicate.

    The provided data is from a real world used example, where what should have been considered a duplicate was missed.
    """

    from models import Content
    from datetime import datetime

    datetime_now = datetime.now()

    first_content = Content(
        id=0,
        subscription_id=38,
        item_id="https://www.bbc.com/news/articles/ced9l7799w9o#0",
        item_guid="https://www.bbc.com/news/articles/ced9l7799w9o#0",
        item_url="https://www.bbc.com/news/articles/ced9l7799w9o",
        item_title="Spain's PM orders 10,000 troops and police to Valencia",
        item_description="",
        item_content_hash="4a2ba8429a0584ce08f521db3f6d3000c248467f2cc6fa4b0458808169247ad8",
        item_image_url="",
        item_thumbnail_url="",
        item_published=datetime_now,
        item_author="",
        item_author_url="",
        item_feed_title="",
        item_feed_url="",
        blocked=False,
    )

    second_content = Content(
        id=1,
        subscription_id=38,
        item_id="https://www.bbc.com/news/articles/ced9l7799w9o#0",
        item_guid="https://www.bbc.com/news/articles/ced9l7799w9o#0",
        item_url="https://www.bbc.com/news/articles/ced9l7799w9o",
        item_title="Spain's PM orders 10,000 troops and police to flood-hit Valencia",
        item_description="",
        item_content_hash="4a2ba8429a0584ce08f521db3f6d3000c248467f2cc6fa4b0458808169247ad8",
        item_image_url="",
        item_thumbnail_url="",
        item_published=datetime_now,
        item_author="",
        item_author_url="",
        item_feed_title="",
        item_feed_url="",
        blocked=False,
    )

    assert first_content.is_duplicate(second_content), "Content is not considered a duplicate"

    print("1 success")

    # BUG: This one is identified but still gets processed...

    third_content = Content(
        id=0,
        subscription_id=38,
        item_id="https://www.bbc.com/sport/formula1/articles/cdd0ey1v5j9o#8",
        item_guid="https://www.bbc.com/sport/formula1/articles/cdd0ey1v5j9o#8",
        item_url="https://www.bbc.com/sport/formula1/articles/cdd0ey1v5j9o",
        item_title="Sao Paulo GP qualifying set for Sunday after rain postponement",
        item_description="",
        item_content_hash="b6c78de554a183cfeca88decf987401719d431647523f038a86fd7d972e4e799",
        item_image_url="",
        item_thumbnail_url="",
        item_published=datetime_now,
        item_author="",
        item_author_url="",
        item_feed_title="",
        item_feed_url="",
        blocked=False,
    )

    fourth_content = Content(
        id=0,
        subscription_id=38,
        item_id="https://www.bbc.com/sport/formula1/articles/cdd0ey1v5j9o#8",
        item_guid="https://www.bbc.com/sport/formula1/articles/cdd0ey1v5j9o#8",
        item_url="https://www.bbc.com/sport/formula1/articles/cdd0ey1v5j9o",
        item_title="Sao Paulo GP qualifying set for Sunday after rain postponement",
        item_description="",
        item_content_hash="6ddd15d7d9626f2d63ba5631056fda9bcaf920e8c82ec5c23fa824b02ce690d0",
        item_image_url="",
        item_thumbnail_url="",
        item_published=datetime_now,
        item_author="",
        item_author_url="",
        item_feed_title="",
        item_feed_url="",
        blocked=False,
    )

    assert third_content.is_duplicate(fourth_content)

    print("2 success")

def main():
    # test_content_filters()
    test_content_duplicates()

if __name__ == "__main__":
    main()
 